#!/bin/bash
##########################################
# Restauration EOLE
# - Zephir -
# LB Dijon 13/01/2006 
# bruno boiget <bruno.boiget@ac-dijon.fr>
# samuel morin <samuel.morin@ac-dijon.fr>
##########################################

# color ASCII codes
#
DEFAULT="\e[0m"
BOLD="\e[1m"
BLACK="\e[30m"
RED="\e[31m"
GREEN="\e[32m"
YELLOW="\e[33m"
BLUE="\e[34m"
VIOLET="\e[35m"
CYAN="\e[36m"
WHITE="\e[37m"

Lock="sauvegarde"
Excl="maj"

RepEole=${RepEole="/usr/share/eole"}
. ParseDico

backup_dir=/var/lib/sphynx_backups

if [ ! -d $backup_dir ]
then
	echo -e "${RED} Erreur, répertoire des sauvegardes non trouvé ${DEFAULT}"
	exit 1
fi
pushd $backup_dir &>/dev/null 2>&1

if [ ! -z $1 ]
then
	archive=$1
        basename=`echo -e $archive | sed -e s/"\.tar\.gz"/""/`
else
	archive=/tmp
fi

while [ ! -f $archive ]
do
	# pas de fichier passé en paramètre
	save_files=`ls *.tar.gz | sed -e s/".tar.gz"/""/`
	echo -e "     Utilitaire de restauration sphynx"
	echo -e
	echo -e "${RED}!!Attention : toutes les modifications effectuées"
	echo -e "  après la sauvegarde restaurée seront perdues!!${DEFAULT}"
	echo -e
	echo -e "${CYAN}liste des sauvegardes présentes :${DEFAULT}"
	echo -e
	echo -e "$save_files"
	echo -e
	read -p "sauvegarde à restaurer (rien pour sortir): " basename
	if [ -z $basename ]
	then
		exit 0
	fi
	if [ -f $basename.tar.gz ]
	then
		archive=$basename.tar.gz
	else
		echo -e "fichier invalide : $basename.tar.gz"
	fi
done

echo -e "décompression en cours..."
tar xzf $archive
cd $basename
echo -e "vérification des données..."
if [ ! -f sphynx.xml ] && 
	[ ! -f sphynx.cfg ]
then
	echo -e "${RED}sauvegarde de la base xml non trouvée${DEFAULT}"
	exit 1
fi
if [ ! -f etc_freeswan.tar ]
then
	echo -e "${RED}sauvegarde des fichiers de conf non trouvée${DEFAULT}"
	exit 1
fi
if [ ! -f home_data.tar ]
then
	echo -e "${RED}sauvegarde des configurations des clients non trouvée${DEFAULT}"
	exit 1
fi
if [ ! -f root_ssh.tar ]
then
	echo -e "${RED}sauvegarde des clefs ssh non trouvée${DEFAULT}"
	exit 1
fi

if [ ! -f etc_eole.tar ]
then
	echo -e "${RED}sauvegarde de la configuration du serveur non trouvée${DEFAULT}"
	exit 1
fi

rep="N"
# restauration des données de la base xml
read -p "Restaurer la base xml et la configuration du generateur (o/n) ?" rep
echo -e
if [ "$rep" == "o" ] || [ "$rep" == "O" ]
then
	echo -e " - base xml + conf generateur"
	cp -f sphynx.xml /usr/share/eole/sphynx-vpn/xml/
	cp -f sphynx.cfg /usr/share/eole/sphynx-vpn/cfg/
fi

# restauration des répertoires et fichiers importants

echo -e " - base ldap"
# restauration de /etc/freeswan
rm -rf /etc/freeswan
tar -C /etc/ -xpf etc_freeswan.tar >/dev/null 2>&1
# regeneration de la conf du serveur
/usr/share/eole/sphynx-vpn/sphynx -t
# relancement ipsec
telinit run ipsec stop
telinit run ipsec start &> /dev/null

echo -e " - configuration des serveurs"
rm -rf /home/data
tar -C /home -xpf home_data.tar >/dev/null 2>&1
# /root/.ssh
rm -rf /root/.ssh
tar -C /root -xpf root_ssh.tar >/dev/null 2>&1
echo -e " - configuration eole"
rm -rf /etc/eole/dicos /etc/eole/patch /etc/eole/config.eol
tar -C /etc/eole -xpf etc_eole.tar >/dev/null 2>&1
# vérification du dictionnaire
echo -e
if [ -f /root/zephir.eol ]
then
	diff -q /root/zephir.eol /etc/eole/config.eol &>/dev/null
	if [ ! $? -eq 0 ]
	then
		mv /root/zephir.eol /root/zephir.eol.bak
		echo -e "${CYAN}Le fichier /root/zephir.eol est différent de la version restaurée"
		echo -e "Le fichier présent actuellement a été renommé en /root/zephir.eol.bak"
		echo -e
		echo -e "Réinstanciez le serveur avec l'un des 2 fichiers sans écraser la base de données${DEFAULT}"
		echo -e
	else
		echo -e "${CYAN}"
		echo -e "Reconfigurez le serveur après la fin de la restauration"
		echo -e "${DEFAULT}"
	fi
fi
cp -f /etc/eole/config.eol /root/zephir.eol
 
# création du fichier de sauvegarde compressé
echo -e "Supression du répertoire temporaire..."
rm -rf $backup_dir/$basename
echo -e "${GREEN}Systeme restauré${DEFAULT}"
echo -e
# retour au répertoire d'origine
popd >/dev/null 2>&1
